/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package dump

import (
	"go.uploadedlobster.com/scotty/internal/config"
	"go.uploadedlobster.com/scotty/internal/models"
)

type DumpBackend struct{}

func (b *DumpBackend) Name() string { return "dump" }

func (b *DumpBackend) Options() []models.BackendOption { return nil }

func (b *DumpBackend) FromConfig(config *config.ServiceConfig) models.Backend {
	return b
}

func (b *DumpBackend) StartImport() error  { return nil }
func (b *DumpBackend) FinishImport() error { return nil }

func (b *DumpBackend) ImportListens(export models.ListensResult, importResult models.ImportResult, progress chan models.Progress) (models.ImportResult, error) {
	for _, listen := range export.Items {
		importResult.UpdateTimestamp(listen.ListenedAt)
		importResult.ImportCount += 1
		progress <- models.Progress{}.FromImportResult(importResult)
		// fmt.Printf("🎶 %v: \"%v\" by %v (%v)\n",
		// 	listen.ListenedAt, listen.TrackName, listen.ArtistName(), listen.RecordingMbid)
	}

	return importResult, nil
}

func (b *DumpBackend) ImportLoves(export models.LovesResult, importResult models.ImportResult, progress chan models.Progress) (models.ImportResult, error) {
	for _, love := range export.Items {
		importResult.UpdateTimestamp(love.Created)
		importResult.ImportCount += 1
		progress <- models.Progress{}.FromImportResult(importResult)
		// fmt.Printf("❤️ %v: \"%v\" by %v (%v)\n",
		// 	love.Created, love.TrackName, love.ArtistName(), love.RecordingMbid)
	}

	return importResult, nil
}
